listener

package
v0.2.3 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Sep 14, 2025 License: MIT Imports: 2 Imported by: 0

Documentation

Index

Constants

const (
	// Label holds the string label denoting the listener type in the database.
	Label = "listener"
	// FieldID holds the string denoting the id field in the database.
	FieldID = "id"
	// FieldName holds the string denoting the name field in the database.
	FieldName = "name"
	// FieldPrivateKey holds the string denoting the private_key field in the database.
	FieldPrivateKey = "private_key"
	// FieldFingerprint holds the string denoting the fingerprint field in the database.
	FieldFingerprint = "fingerprint"
	// Table holds the table name of the listener in the database.
	Table = "listeners"
)

Variables

var (
	// NameValidator is a validator for the "name" field. It is called by the builders before save.
	NameValidator func(string) error
	// PrivateKeyValidator is a validator for the "private_key" field. It is called by the builders before save.
	PrivateKeyValidator func([]byte) error
	// FingerprintValidator is a validator for the "fingerprint" field. It is called by the builders before save.
	FingerprintValidator func(string) error
	// DefaultID holds the default value on creation for the "id" field.
	DefaultID func() string
)

Columns holds all SQL columns for listener fields.

Functions

func And

func And(predicates ...predicate.Listener) predicate.Listener

And groups predicates with the AND operator between them.

func Fingerprint

func Fingerprint(v string) predicate.Listener

Fingerprint applies equality check predicate on the "fingerprint" field. It's identical to FingerprintEQ.

func FingerprintContains

func FingerprintContains(v string) predicate.Listener

FingerprintContains applies the Contains predicate on the "fingerprint" field.

func FingerprintContainsFold

func FingerprintContainsFold(v string) predicate.Listener

FingerprintContainsFold applies the ContainsFold predicate on the "fingerprint" field.

func FingerprintEQ

func FingerprintEQ(v string) predicate.Listener

FingerprintEQ applies the EQ predicate on the "fingerprint" field.

func FingerprintEqualFold

func FingerprintEqualFold(v string) predicate.Listener

FingerprintEqualFold applies the EqualFold predicate on the "fingerprint" field.

func FingerprintGT

func FingerprintGT(v string) predicate.Listener

FingerprintGT applies the GT predicate on the "fingerprint" field.

func FingerprintGTE

func FingerprintGTE(v string) predicate.Listener

FingerprintGTE applies the GTE predicate on the "fingerprint" field.

func FingerprintHasPrefix

func FingerprintHasPrefix(v string) predicate.Listener

FingerprintHasPrefix applies the HasPrefix predicate on the "fingerprint" field.

func FingerprintHasSuffix

func FingerprintHasSuffix(v string) predicate.Listener

FingerprintHasSuffix applies the HasSuffix predicate on the "fingerprint" field.

func FingerprintIn

func FingerprintIn(vs ...string) predicate.Listener

FingerprintIn applies the In predicate on the "fingerprint" field.

func FingerprintLT

func FingerprintLT(v string) predicate.Listener

FingerprintLT applies the LT predicate on the "fingerprint" field.

func FingerprintLTE

func FingerprintLTE(v string) predicate.Listener

FingerprintLTE applies the LTE predicate on the "fingerprint" field.

func FingerprintNEQ

func FingerprintNEQ(v string) predicate.Listener

FingerprintNEQ applies the NEQ predicate on the "fingerprint" field.

func FingerprintNotIn

func FingerprintNotIn(vs ...string) predicate.Listener

FingerprintNotIn applies the NotIn predicate on the "fingerprint" field.

func ID

func ID(id string) predicate.Listener

ID filters vertices based on their ID field.

func IDContainsFold

func IDContainsFold(id string) predicate.Listener

IDContainsFold applies the ContainsFold predicate on the ID field.

func IDEQ

func IDEQ(id string) predicate.Listener

IDEQ applies the EQ predicate on the ID field.

func IDEqualFold

func IDEqualFold(id string) predicate.Listener

IDEqualFold applies the EqualFold predicate on the ID field.

func IDGT

func IDGT(id string) predicate.Listener

IDGT applies the GT predicate on the ID field.

func IDGTE

func IDGTE(id string) predicate.Listener

IDGTE applies the GTE predicate on the ID field.

func IDIn

func IDIn(ids ...string) predicate.Listener

IDIn applies the In predicate on the ID field.

func IDLT

func IDLT(id string) predicate.Listener

IDLT applies the LT predicate on the ID field.

func IDLTE

func IDLTE(id string) predicate.Listener

IDLTE applies the LTE predicate on the ID field.

func IDNEQ

func IDNEQ(id string) predicate.Listener

IDNEQ applies the NEQ predicate on the ID field.

func IDNotIn

func IDNotIn(ids ...string) predicate.Listener

IDNotIn applies the NotIn predicate on the ID field.

func Name

func Name(v string) predicate.Listener

Name applies equality check predicate on the "name" field. It's identical to NameEQ.

func NameContains

func NameContains(v string) predicate.Listener

NameContains applies the Contains predicate on the "name" field.

func NameContainsFold

func NameContainsFold(v string) predicate.Listener

NameContainsFold applies the ContainsFold predicate on the "name" field.

func NameEQ

func NameEQ(v string) predicate.Listener

NameEQ applies the EQ predicate on the "name" field.

func NameEqualFold

func NameEqualFold(v string) predicate.Listener

NameEqualFold applies the EqualFold predicate on the "name" field.

func NameGT

func NameGT(v string) predicate.Listener

NameGT applies the GT predicate on the "name" field.

func NameGTE

func NameGTE(v string) predicate.Listener

NameGTE applies the GTE predicate on the "name" field.

func NameHasPrefix

func NameHasPrefix(v string) predicate.Listener

NameHasPrefix applies the HasPrefix predicate on the "name" field.

func NameHasSuffix

func NameHasSuffix(v string) predicate.Listener

NameHasSuffix applies the HasSuffix predicate on the "name" field.

func NameIn

func NameIn(vs ...string) predicate.Listener

NameIn applies the In predicate on the "name" field.

func NameLT

func NameLT(v string) predicate.Listener

NameLT applies the LT predicate on the "name" field.

func NameLTE

func NameLTE(v string) predicate.Listener

NameLTE applies the LTE predicate on the "name" field.

func NameNEQ

func NameNEQ(v string) predicate.Listener

NameNEQ applies the NEQ predicate on the "name" field.

func NameNotIn

func NameNotIn(vs ...string) predicate.Listener

NameNotIn applies the NotIn predicate on the "name" field.

func Not

Not applies the not operator on the given predicate.

func Or

func Or(predicates ...predicate.Listener) predicate.Listener

Or groups predicates with the OR operator between them.

func PrivateKey

func PrivateKey(v []byte) predicate.Listener

PrivateKey applies equality check predicate on the "private_key" field. It's identical to PrivateKeyEQ.

func PrivateKeyEQ

func PrivateKeyEQ(v []byte) predicate.Listener

PrivateKeyEQ applies the EQ predicate on the "private_key" field.

func PrivateKeyGT

func PrivateKeyGT(v []byte) predicate.Listener

PrivateKeyGT applies the GT predicate on the "private_key" field.

func PrivateKeyGTE

func PrivateKeyGTE(v []byte) predicate.Listener

PrivateKeyGTE applies the GTE predicate on the "private_key" field.

func PrivateKeyIn

func PrivateKeyIn(vs ...[]byte) predicate.Listener

PrivateKeyIn applies the In predicate on the "private_key" field.

func PrivateKeyLT

func PrivateKeyLT(v []byte) predicate.Listener

PrivateKeyLT applies the LT predicate on the "private_key" field.

func PrivateKeyLTE

func PrivateKeyLTE(v []byte) predicate.Listener

PrivateKeyLTE applies the LTE predicate on the "private_key" field.

func PrivateKeyNEQ

func PrivateKeyNEQ(v []byte) predicate.Listener

PrivateKeyNEQ applies the NEQ predicate on the "private_key" field.

func PrivateKeyNotIn

func PrivateKeyNotIn(vs ...[]byte) predicate.Listener

PrivateKeyNotIn applies the NotIn predicate on the "private_key" field.

func ValidColumn

func ValidColumn(column string) bool

ValidColumn reports if the column name is valid (part of the table columns).

Types

type OrderOption

type OrderOption func(*sql.Selector)

OrderOption defines the ordering options for the Listener queries.

func ByFingerprint

func ByFingerprint(opts ...sql.OrderTermOption) OrderOption

ByFingerprint orders the results by the fingerprint field.

func ByID

func ByID(opts ...sql.OrderTermOption) OrderOption

ByID orders the results by the id field.

func ByName

func ByName(opts ...sql.OrderTermOption) OrderOption

ByName orders the results by the name field.

Jump to