Documentation
¶
Index ¶
- Constants
- Variables
- func And(predicates ...predicate.Listener) predicate.Listener
- func Fingerprint(v string) predicate.Listener
- func FingerprintContains(v string) predicate.Listener
- func FingerprintContainsFold(v string) predicate.Listener
- func FingerprintEQ(v string) predicate.Listener
- func FingerprintEqualFold(v string) predicate.Listener
- func FingerprintGT(v string) predicate.Listener
- func FingerprintGTE(v string) predicate.Listener
- func FingerprintHasPrefix(v string) predicate.Listener
- func FingerprintHasSuffix(v string) predicate.Listener
- func FingerprintIn(vs ...string) predicate.Listener
- func FingerprintLT(v string) predicate.Listener
- func FingerprintLTE(v string) predicate.Listener
- func FingerprintNEQ(v string) predicate.Listener
- func FingerprintNotIn(vs ...string) predicate.Listener
- func ID(id string) predicate.Listener
- func IDContainsFold(id string) predicate.Listener
- func IDEQ(id string) predicate.Listener
- func IDEqualFold(id string) predicate.Listener
- func IDGT(id string) predicate.Listener
- func IDGTE(id string) predicate.Listener
- func IDIn(ids ...string) predicate.Listener
- func IDLT(id string) predicate.Listener
- func IDLTE(id string) predicate.Listener
- func IDNEQ(id string) predicate.Listener
- func IDNotIn(ids ...string) predicate.Listener
- func Name(v string) predicate.Listener
- func NameContains(v string) predicate.Listener
- func NameContainsFold(v string) predicate.Listener
- func NameEQ(v string) predicate.Listener
- func NameEqualFold(v string) predicate.Listener
- func NameGT(v string) predicate.Listener
- func NameGTE(v string) predicate.Listener
- func NameHasPrefix(v string) predicate.Listener
- func NameHasSuffix(v string) predicate.Listener
- func NameIn(vs ...string) predicate.Listener
- func NameLT(v string) predicate.Listener
- func NameLTE(v string) predicate.Listener
- func NameNEQ(v string) predicate.Listener
- func NameNotIn(vs ...string) predicate.Listener
- func Not(p predicate.Listener) predicate.Listener
- func Or(predicates ...predicate.Listener) predicate.Listener
- func PrivateKey(v []byte) predicate.Listener
- func PrivateKeyEQ(v []byte) predicate.Listener
- func PrivateKeyGT(v []byte) predicate.Listener
- func PrivateKeyGTE(v []byte) predicate.Listener
- func PrivateKeyIn(vs ...[]byte) predicate.Listener
- func PrivateKeyLT(v []byte) predicate.Listener
- func PrivateKeyLTE(v []byte) predicate.Listener
- func PrivateKeyNEQ(v []byte) predicate.Listener
- func PrivateKeyNotIn(vs ...[]byte) predicate.Listener
- func ValidColumn(column string) bool
- type OrderOption
Constants ¶
const ( // Label holds the string label denoting the listener type in the database. Label = "listener" // FieldID holds the string denoting the id field in the database. FieldID = "id" // FieldName holds the string denoting the name field in the database. FieldName = "name" // FieldPrivateKey holds the string denoting the private_key field in the database. FieldPrivateKey = "private_key" // FieldFingerprint holds the string denoting the fingerprint field in the database. FieldFingerprint = "fingerprint" // Table holds the table name of the listener in the database. Table = "listeners" )
Variables ¶
var ( // NameValidator is a validator for the "name" field. It is called by the builders before save. NameValidator func(string) error // PrivateKeyValidator is a validator for the "private_key" field. It is called by the builders before save. PrivateKeyValidator func([]byte) error // FingerprintValidator is a validator for the "fingerprint" field. It is called by the builders before save. FingerprintValidator func(string) error // DefaultID holds the default value on creation for the "id" field. DefaultID func() string )
var Columns = []string{ FieldID, FieldName, FieldPrivateKey, FieldFingerprint, }
Columns holds all SQL columns for listener fields.
Functions ¶
func Fingerprint ¶
Fingerprint applies equality check predicate on the "fingerprint" field. It's identical to FingerprintEQ.
func FingerprintContains ¶
FingerprintContains applies the Contains predicate on the "fingerprint" field.
func FingerprintContainsFold ¶
FingerprintContainsFold applies the ContainsFold predicate on the "fingerprint" field.
func FingerprintEQ ¶
FingerprintEQ applies the EQ predicate on the "fingerprint" field.
func FingerprintEqualFold ¶
FingerprintEqualFold applies the EqualFold predicate on the "fingerprint" field.
func FingerprintGT ¶
FingerprintGT applies the GT predicate on the "fingerprint" field.
func FingerprintGTE ¶
FingerprintGTE applies the GTE predicate on the "fingerprint" field.
func FingerprintHasPrefix ¶
FingerprintHasPrefix applies the HasPrefix predicate on the "fingerprint" field.
func FingerprintHasSuffix ¶
FingerprintHasSuffix applies the HasSuffix predicate on the "fingerprint" field.
func FingerprintIn ¶
FingerprintIn applies the In predicate on the "fingerprint" field.
func FingerprintLT ¶
FingerprintLT applies the LT predicate on the "fingerprint" field.
func FingerprintLTE ¶
FingerprintLTE applies the LTE predicate on the "fingerprint" field.
func FingerprintNEQ ¶
FingerprintNEQ applies the NEQ predicate on the "fingerprint" field.
func FingerprintNotIn ¶
FingerprintNotIn applies the NotIn predicate on the "fingerprint" field.
func IDContainsFold ¶
IDContainsFold applies the ContainsFold predicate on the ID field.
func IDEqualFold ¶
IDEqualFold applies the EqualFold predicate on the ID field.
func NameContains ¶
NameContains applies the Contains predicate on the "name" field.
func NameContainsFold ¶
NameContainsFold applies the ContainsFold predicate on the "name" field.
func NameEqualFold ¶
NameEqualFold applies the EqualFold predicate on the "name" field.
func NameHasPrefix ¶
NameHasPrefix applies the HasPrefix predicate on the "name" field.
func NameHasSuffix ¶
NameHasSuffix applies the HasSuffix predicate on the "name" field.
func PrivateKey ¶
PrivateKey applies equality check predicate on the "private_key" field. It's identical to PrivateKeyEQ.
func PrivateKeyEQ ¶
PrivateKeyEQ applies the EQ predicate on the "private_key" field.
func PrivateKeyGT ¶
PrivateKeyGT applies the GT predicate on the "private_key" field.
func PrivateKeyGTE ¶
PrivateKeyGTE applies the GTE predicate on the "private_key" field.
func PrivateKeyIn ¶
PrivateKeyIn applies the In predicate on the "private_key" field.
func PrivateKeyLT ¶
PrivateKeyLT applies the LT predicate on the "private_key" field.
func PrivateKeyLTE ¶
PrivateKeyLTE applies the LTE predicate on the "private_key" field.
func PrivateKeyNEQ ¶
PrivateKeyNEQ applies the NEQ predicate on the "private_key" field.
func PrivateKeyNotIn ¶
PrivateKeyNotIn applies the NotIn predicate on the "private_key" field.
func ValidColumn ¶
ValidColumn reports if the column name is valid (part of the table columns).
Types ¶
type OrderOption ¶
OrderOption defines the ordering options for the Listener queries.
func ByFingerprint ¶
func ByFingerprint(opts ...sql.OrderTermOption) OrderOption
ByFingerprint orders the results by the fingerprint field.
func ByID ¶
func ByID(opts ...sql.OrderTermOption) OrderOption
ByID orders the results by the id field.
func ByName ¶
func ByName(opts ...sql.OrderTermOption) OrderOption
ByName orders the results by the name field.